{
  config,
  lib,
  pkgs,
  ...
}:
let
  vars = import ../vars.nix;
in
{
  virtualisation.oci-containers.containers = {
    bazarr = {
      image = "ghcr.io/linuxserver/bazarr:latest";
      ports = [ "6767:6767" ];
      environment = {
        PUID = "600";
        PGID = "100";
        TZ = "America/New_York";
      };
      volumes = [
        "${vars.primary_docker}/bazarr:/config"
        "${vars.primary_plex_storage}/data:/data"
      ];
      autoStart = true;
    };
    prowlarr = {
      image = "ghcr.io/linuxserver/prowlarr:latest";
      ports = [ "9696:9696" ];
      environment = {
        PUID = "600";
        PGID = "100";
        TZ = "America/New_York";
      };
      volumes = [ "${vars.primary_docker}/prowlarr:/config" ];
      autoStart = true;
    };
    radarr = {
      image = "ghcr.io/linuxserver/radarr:latest";
      ports = [ "7878:7878" ];
      environment = {
        PUID = "600";
        PGID = "100";
        TZ = "America/New_York";
      };
      volumes = [
        "${vars.primary_docker}/radarr:/config"
        "${vars.primary_plex_storage}/data:/data"
      ];
      autoStart = true;
    };
    sonarr = {
      image = "ghcr.io/linuxserver/sonarr:latest";
      ports = [ "8989:8989" ];
      environment = {
        PUID = "600";
        PGID = "100";
        TZ = "America/New_York";
      };
      volumes = [
        "${vars.primary_docker}/sonarr:/config"
        "${vars.primary_plex_storage}/data:/data"
      ];
      autoStart = true;
    };
    lidarr = {
      image = "ghcr.io/linuxserver/lidarr:latest";
      ports = [ "8686:8686" ];
      environment = {
        PUID = "600";
        PGID = "100";
        TZ = "America/New_York";
      };
      volumes = [
        "${vars.primary_docker}/lidarr:/config"
        "${vars.primary_plex_storage}/data:/data"
      ];
      autoStart = true;
    };
    readarr = {
      image = "ghcr.io/linuxserver/readarr:latest";
      ports = [ "8787:8787" ];
      environment = {
        PUID = "600";
        PGID = "100";
        TZ = "America/New_York";
      };
      volumes = [
        "${vars.primary_docker}/readarr:/config"
        "${vars.primary_plex_storage}/data:/data"
      ];
      autoStart = true;
    };
    unpackerr = {
      image = "golift/unpackerr:latest";
      user = "600:100";
      environment = {
        TZ = "America/New_York";
      };
      volumes = [
        "${vars.primary_docker}/unpackerr:/config"
        "${vars.primary_plex_storage}:/data"
      ];
      autoStart = true;
    };

    overseerr = {
      image = "lscr.io/linuxserver/overseerr";
      environment = {
        PUID = "600";
        PGID = "100";
        TZ = "America/New_York";
      };
      volumes = [ "${vars.primary_docker}/overseerr:/config" ];
      # TODO: remove ports later since this is going through web
      ports = [ "5055:5055" ]; # Web UI port
      dependsOn = [
        "radarr"
        "sonarr"
      ];
      extraOptions = [ "--network=haproxy-net" ];
      autoStart = true;
    };
  };
}
